CVS commit: src/sys

2022-01-25 Thread Andrius Varanavicius
Module Name:src
Committed By:   andvar
Date:   Tue Jan 25 22:01:35 UTC 2022

Modified Files:
src/sys/arch/evbarm/smdk2xx0: smdk2410_kbd.c
src/sys/arch/m68k/fpsp: x_unfl.sa
src/sys/dev/ieee1394: fwohci.c
src/sys/dev/microcode/aic7xxx: aic79xx.reg aic79xx.seq aic7xxx.reg
aic7xxx.seq
src/sys/dev/pci: auixp.c autri.c
src/sys/fs/udf: udf_subr.c

Log Message:
fix various typos in comments.


To generate a diff of this commit:
cvs rdiff -u -r1.10 -r1.11 src/sys/arch/evbarm/smdk2xx0/smdk2410_kbd.c
cvs rdiff -u -r1.4 -r1.5 src/sys/arch/m68k/fpsp/x_unfl.sa
cvs rdiff -u -r1.149 -r1.150 src/sys/dev/ieee1394/fwohci.c
cvs rdiff -u -r1.14 -r1.15 src/sys/dev/microcode/aic7xxx/aic79xx.reg
cvs rdiff -u -r1.15 -r1.16 src/sys/dev/microcode/aic7xxx/aic79xx.seq
cvs rdiff -u -r1.5 -r1.6 src/sys/dev/microcode/aic7xxx/aic7xxx.reg
cvs rdiff -u -r1.21 -r1.22 src/sys/dev/microcode/aic7xxx/aic7xxx.seq
cvs rdiff -u -r1.52 -r1.53 src/sys/dev/pci/auixp.c
cvs rdiff -u -r1.59 -r1.60 src/sys/dev/pci/autri.c
cvs rdiff -u -r1.164 -r1.165 src/sys/fs/udf/udf_subr.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbarm/smdk2xx0/smdk2410_kbd.c
diff -u src/sys/arch/evbarm/smdk2xx0/smdk2410_kbd.c:1.10 src/sys/arch/evbarm/smdk2xx0/smdk2410_kbd.c:1.11
--- src/sys/arch/evbarm/smdk2xx0/smdk2410_kbd.c:1.10	Sat Aug  7 16:18:50 2021
+++ src/sys/arch/evbarm/smdk2xx0/smdk2410_kbd.c	Tue Jan 25 22:01:34 2022
@@ -1,4 +1,4 @@
-/* $NetBSD: smdk2410_kbd.c,v 1.10 2021/08/07 16:18:50 thorpej Exp $ */
+/* $NetBSD: smdk2410_kbd.c,v 1.11 2022/01/25 22:01:34 andvar Exp $ */
 
 /*
  * Copyright (c) 2004  Genetec Corporation.  All rights reserved.
@@ -40,7 +40,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: smdk2410_kbd.c,v 1.10 2021/08/07 16:18:50 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: smdk2410_kbd.c,v 1.11 2022/01/25 22:01:34 andvar Exp $");
 
 #include 
 #include 
@@ -72,7 +72,7 @@ __KERNEL_RCSID(0, "$NetBSD: smdk2410_kbd
  */
 
 /*
- * Commands/responce 
+ * Commands/response 
  */
 #define	KCDR_INITIALIZE	0xa0	/* Initialize request */
 #define	KCDR_INITCOMP	0xa1	/* Initialize complete */

Index: src/sys/arch/m68k/fpsp/x_unfl.sa
diff -u src/sys/arch/m68k/fpsp/x_unfl.sa:1.4 src/sys/arch/m68k/fpsp/x_unfl.sa:1.5
--- src/sys/arch/m68k/fpsp/x_unfl.sa:1.4	Sun Sep 16 16:34:32 2001
+++ src/sys/arch/m68k/fpsp/x_unfl.sa	Tue Jan 25 22:01:34 2022
@@ -1,4 +1,4 @@
-*	$NetBSD: x_unfl.sa,v 1.4 2001/09/16 16:34:32 wiz Exp $
+*	$NetBSD: x_unfl.sa,v 1.5 2022/01/25 22:01:34 andvar Exp $
 
 *	MOTOROLA MICROPROCESSOR & MEMORY TECHNOLOGY GROUP
 *	M68000 Hi-Performance Microprocessor Division
@@ -41,7 +41,7 @@
 * by taking the intermediate result (which is always normalized) and 
 * shifting the mantissa right while incrementing the exponent until 
 * it is equal to the denormalized exponent for the destination 
-* format.  After denormalizatoin, the result is rounded to the 
+* format.  After denormalization, the result is rounded to the 
 * destination format.
 *		
 * Trap enabled results

Index: src/sys/dev/ieee1394/fwohci.c
diff -u src/sys/dev/ieee1394/fwohci.c:1.149 src/sys/dev/ieee1394/fwohci.c:1.150
--- src/sys/dev/ieee1394/fwohci.c:1.149	Sun Dec  5 08:17:21 2021
+++ src/sys/dev/ieee1394/fwohci.c	Tue Jan 25 22:01:34 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: fwohci.c,v 1.149 2021/12/05 08:17:21 msaitoh Exp $	*/
+/*	$NetBSD: fwohci.c,v 1.150 2022/01/25 22:01:34 andvar Exp $	*/
 
 /*-
  * Copyright (c) 2003 Hidetoshi Shimokawa
@@ -37,7 +37,7 @@
  *
  */
 #include 
-__KERNEL_RCSID(0, "$NetBSD: fwohci.c,v 1.149 2021/12/05 08:17:21 msaitoh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: fwohci.c,v 1.150 2022/01/25 22:01:34 andvar Exp $");
 
 #include 
 #include 
@@ -1419,7 +1419,7 @@ txloop:
 	OHCI_OUTPUT_MORE | OHCI_KEY_ST2 | hdr_len);
  	FWOHCI_DMA_WRITE(db->db.desc.addr, 0);
  	FWOHCI_DMA_WRITE(db->db.desc.res, 0);
-/* Specify bound timer of asy. responce */
+/* Specify bound timer of asy. response */
 	if (dbch->off != OHCI_ATSOFF)
  		FWOHCI_DMA_WRITE(db->db.desc.res,
 		 (OREAD(sc, OHCI_CYCLETIMER) >> 12) + (1 << 13));

Index: src/sys/dev/microcode/aic7xxx/aic79xx.reg
diff -u src/sys/dev/microcode/aic7xxx/aic79xx.reg:1.14 src/sys/dev/microcode/aic7xxx/aic79xx.reg:1.15
--- src/sys/dev/microcode/aic7xxx/aic79xx.reg:1.14	Tue May 28 08:59:34 2019
+++ src/sys/dev/microcode/aic7xxx/aic79xx.reg	Tue Jan 25 22:01:34 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: aic79xx.reg,v 1.14 2019/05/28 08:59:34 msaitoh Exp $	*/
+/*	$NetBSD: aic79xx.reg,v 1.15 2022/01/25 22:01:34 andvar Exp $	*/
 
 /*
  * Aic79xx register and scratch ram definitions.
@@ -2433,7 +2433,7 @@ register IOPDNCTL {
 }
 
 /*
- * Shaddow Host Address.
+ * Shadow Host Address.
  */
 register SHADDR {
 	address			0x060

Index: src/sys/dev/microcode/aic7xxx/aic79xx.seq
diff -u src/sys/dev/microcode/aic7xxx/aic79xx.seq:1.15 src/sys/dev/microcode/aic7xxx/aic79xx.seq:1.16

CVS commit: src/sys

2022-01-25 Thread Andrius Varanavicius
Module Name:src
Committed By:   andvar
Date:   Tue Jan 25 22:01:35 UTC 2022

Modified Files:
src/sys/arch/evbarm/smdk2xx0: smdk2410_kbd.c
src/sys/arch/m68k/fpsp: x_unfl.sa
src/sys/dev/ieee1394: fwohci.c
src/sys/dev/microcode/aic7xxx: aic79xx.reg aic79xx.seq aic7xxx.reg
aic7xxx.seq
src/sys/dev/pci: auixp.c autri.c
src/sys/fs/udf: udf_subr.c

Log Message:
fix various typos in comments.


To generate a diff of this commit:
cvs rdiff -u -r1.10 -r1.11 src/sys/arch/evbarm/smdk2xx0/smdk2410_kbd.c
cvs rdiff -u -r1.4 -r1.5 src/sys/arch/m68k/fpsp/x_unfl.sa
cvs rdiff -u -r1.149 -r1.150 src/sys/dev/ieee1394/fwohci.c
cvs rdiff -u -r1.14 -r1.15 src/sys/dev/microcode/aic7xxx/aic79xx.reg
cvs rdiff -u -r1.15 -r1.16 src/sys/dev/microcode/aic7xxx/aic79xx.seq
cvs rdiff -u -r1.5 -r1.6 src/sys/dev/microcode/aic7xxx/aic7xxx.reg
cvs rdiff -u -r1.21 -r1.22 src/sys/dev/microcode/aic7xxx/aic7xxx.seq
cvs rdiff -u -r1.52 -r1.53 src/sys/dev/pci/auixp.c
cvs rdiff -u -r1.59 -r1.60 src/sys/dev/pci/autri.c
cvs rdiff -u -r1.164 -r1.165 src/sys/fs/udf/udf_subr.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/tests/lib/libcurses

2022-01-25 Thread Brett Lymn
Module Name:src
Committed By:   blymn
Date:   Tue Jan 25 21:28:49 UTC 2022

Modified Files:
src/tests/lib/libcurses: t_curses.sh

Log Message:
Remove excess shift since locale is no longer passed


To generate a diff of this commit:
cvs rdiff -u -r1.26 -r1.27 src/tests/lib/libcurses/t_curses.sh

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/tests/lib/libcurses

2022-01-25 Thread Brett Lymn
Module Name:src
Committed By:   blymn
Date:   Tue Jan 25 21:28:49 UTC 2022

Modified Files:
src/tests/lib/libcurses: t_curses.sh

Log Message:
Remove excess shift since locale is no longer passed


To generate a diff of this commit:
cvs rdiff -u -r1.26 -r1.27 src/tests/lib/libcurses/t_curses.sh

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/tests/lib/libcurses/t_curses.sh
diff -u src/tests/lib/libcurses/t_curses.sh:1.26 src/tests/lib/libcurses/t_curses.sh:1.27
--- src/tests/lib/libcurses/t_curses.sh:1.26	Tue Jan 25 03:23:05 2022
+++ src/tests/lib/libcurses/t_curses.sh	Tue Jan 25 21:28:49 2022
@@ -9,7 +9,7 @@ h_run()
 	else
 		# export the locale and shift the parameters by two and pass the rest
 		export LC_ALL=$locale
-		shift 2
+		shift
 		r_run $file $@
 	fi
 }



CVS commit: src/sys/dev/pci

2022-01-25 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Tue Jan 25 16:07:57 UTC 2022

Modified Files:
src/sys/dev/pci: ichsmb.c

Log Message:
Add Intel 600 Series PCH (desktop) support.


To generate a diff of this commit:
cvs rdiff -u -r1.75 -r1.76 src/sys/dev/pci/ichsmb.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/ichsmb.c
diff -u src/sys/dev/pci/ichsmb.c:1.75 src/sys/dev/pci/ichsmb.c:1.76
--- src/sys/dev/pci/ichsmb.c:1.75	Wed Oct 27 18:50:57 2021
+++ src/sys/dev/pci/ichsmb.c	Tue Jan 25 16:07:57 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: ichsmb.c,v 1.75 2021/10/27 18:50:57 msaitoh Exp $	*/
+/*	$NetBSD: ichsmb.c,v 1.76 2022/01/25 16:07:57 msaitoh Exp $	*/
 /*	$OpenBSD: ichiic.c,v 1.44 2020/10/07 11:23:05 jsg Exp $	*/
 
 /*
@@ -22,7 +22,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: ichsmb.c,v 1.75 2021/10/27 18:50:57 msaitoh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ichsmb.c,v 1.76 2022/01/25 16:07:57 msaitoh Exp $");
 
 #include 
 #include 
@@ -153,6 +153,7 @@ ichsmb_match(device_t parent, cfdata_t m
 		case PCI_PRODUCT_INTEL_495_YU_SMB:
 		case PCI_PRODUCT_INTEL_5HS_H_SMB:
 		case PCI_PRODUCT_INTEL_5HS_LP_SMB:
+		case PCI_PRODUCT_INTEL_6HS_H_SMB:
 			return 1;
 		}
 	}



CVS commit: src/sys/dev/pci

2022-01-25 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Tue Jan 25 16:07:57 UTC 2022

Modified Files:
src/sys/dev/pci: ichsmb.c

Log Message:
Add Intel 600 Series PCH (desktop) support.


To generate a diff of this commit:
cvs rdiff -u -r1.75 -r1.76 src/sys/dev/pci/ichsmb.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/dev/pci

2022-01-25 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Tue Jan 25 16:07:15 UTC 2022

Modified Files:
src/sys/dev/pci: pcidevs.h pcidevs_data.h

Log Message:
Regen.


To generate a diff of this commit:
cvs rdiff -u -r1.1430 -r1.1431 src/sys/dev/pci/pcidevs.h
cvs rdiff -u -r1.1429 -r1.1430 src/sys/dev/pci/pcidevs_data.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/dev/pci

2022-01-25 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Tue Jan 25 16:06:44 UTC 2022

Modified Files:
src/sys/dev/pci: pcidevs

Log Message:
Add Alder Lake devices and Intel 600 Series PCH devices.


To generate a diff of this commit:
cvs rdiff -u -r1.1445 -r1.1446 src/sys/dev/pci/pcidevs

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/pcidevs
diff -u src/sys/dev/pci/pcidevs:1.1445 src/sys/dev/pci/pcidevs:1.1446
--- src/sys/dev/pci/pcidevs:1.1445	Sat Jan  1 10:32:29 2022
+++ src/sys/dev/pci/pcidevs	Tue Jan 25 16:06:44 2022
@@ -1,4 +1,4 @@
-$NetBSD: pcidevs,v 1.1445 2022/01/01 10:32:29 msaitoh Exp $
+$NetBSD: pcidevs,v 1.1446 2022/01/25 16:06:44 msaitoh Exp $
 
 /*
  * Copyright (c) 1995, 1996 Christopher G. Demetriou
@@ -5646,6 +5646,41 @@ product INTEL EHL_GPU_32	0x4551	Elkhart 
 product INTEL EHL_DPTF		0x4503	Elkhart Lake DPTF
 product INTEL EHL_GNA		0x4511	Elkhart Lake GNA
 product INTEL EHL_TRACE_2	0x4529	Elkhart Lake Trace Hub (Compute Die)
+product INTEL ADL_PCIE_RP_0	0x460d	Alder Lake PCIe G5 Root Port 0 (x16)
+product INTEL ADL_XDCI		0x460e	Alder Lake USB-C Device (xDCI)
+product INTEL ADL_S_2_0_HOST	0x4610	Alder Lake (S,2+0) Host
+product INTEL ADL_DTT		0x461d	Alder Lake Dynamic Tuning Technology
+product INTEL ADL_XHCI		0x461e	Alder Lake USB-C Host (xHCI)
+product INTEL ADL_TBT_PCIE_3	0x461f	Alder Lake Thunderbolt PCIe 3
+product INTEL ADL_H_4_8_HOST	0x4621	Alder Lake (H,4+8) Host
+product INTEL ADL_H_4_4_HOST	0x4629	Alder Lake (H,4+4) Host
+product INTEL ADL_PCIE_RP_1	0x462d	Alder Lake PCIe G5 Root Port 1 (x8)
+product INTEL ADL_TBT_PCIE_2	0x462f	Alder Lake Thunderbolt PCIe 2
+product INTEL ADL_S_4_0_HOST	0x4630	Alder Lake (S,4+0) Host
+product INTEL ADL_PCIE_RP_3	0x463d	Alder Lake PCIe G4 Root Port 3 (x4)
+product INTEL ADL_TBTDMA_0	0x463e	Alder Lake Thunderbolt DMA 0
+product INTEL ADL_TBT_PCIE_1	0x463f	Alder Lake Thunderbolt PCIe 1
+product INTEL ADL_H_6_8_HOST	0x4641	Alder Lake (H,6+8) Host
+product INTEL ADL_S_6_4_HOST	0x4648	Alder Lake (S,6+4) Host
+product INTEL ADL_H_6_4_HOST	0x4649	Alder Lake (H,6+4) Host
+product INTEL ADL_PCIE_RP_2	0x464d	Alder Lake PCIe G4 Root Port 2 (x4)
+product INTEL ADL_GNA		0x464f	Alder Lake Gauss Newton Algorithm
+product INTEL ADL_S_6_0_HOST	0x4650	Alder Lake (S,6+0) Host
+product INTEL ADL_IPU		0x465d	Alder Lake Image Processing Unit
+product INTEL ADL_S_8_8_HOST	0x4660	Alder Lake (S,8+8) Host
+product INTEL ADL_S_8_4_HOST	0x4668	Alder Lake (S,8+4) Host
+product INTEL ADL_TBTDMA_1	0x466d	Alder Lake Thunderbolt DMA 1
+product INTEL ADL_TBT_PCIE_0	0x466e	Alder Lake Thunderbolt PCIe 0
+product INTEL ADL_TRACE		0x466f	Alder Lake Trace Hub (Compute Die?XXX)
+product INTEL ADL_CLSRAM	0x467d	Alder Lake Crash Log & Telemetry
+product INTEL ADL_VMD		0x467f	Alder Lake Volume Management Device
+product INTEL ADL_IGD_1		0x4680	Alder Lake Graphics (32EU)
+product INTEL ADL_IGD_2		0x4682	Alder Lake Graphics (24EU)
+product INTEL ADL_IGD_3		0x4690	Alder Lake Graphics (32EU)
+product INTEL ADL_IGD_4		0x4692	Alder Lake Graphics (24EU)
+product INTEL ADL_IGD_5		0x4693	Alder Lake Graphics (16EU)
+product INTEL ADL_IGD_6		0x46a6	Alder Lake Graphics
+product INTEL ADL_IGD_7		0x46a3	Alder Lake Graphics
 product INTEL EHL_ESPI		0x4b00	Elkhart Lake eSPI
 product INTEL EHL_P2SB		0x4b20	Elkhart Lake P2SB
 product INTEL EHL_PMC		0x4b21	Elkhart Lake PMC
@@ -6031,6 +6066,69 @@ product INTEL 82443GX		0x71a0	82443GX Ho
 product INTEL 82443GX_AGP	0x71a1	82443GX AGP Interface
 product INTEL 82443GX_NOAGP	0x71a2	82443GX Host Bridge/Controller (AGP disabled)
 product INTEL I740		0x7800	i740 Graphics Accelerator
+product INTEL 6HS_Z690_ESPI	0x7a84	Z690 eSPI
+product INTEL 6HS_H670_ESPI	0x7a85	H670 eSPI
+product INTEL 6HS_B660_ESPI	0x7a86	B660 eSPI
+product INTEL 6HS_H610_ESPI	0x7a87	H610 eSPI
+product INTEL 6HS_H_P2SB	0x7aa0	600 Series PCH-H P2SB
+product INTEL 6HS_H_PMC		0x7aa1	600 Series PCH-H PMC
+product INTEL 6HS_H_SMB		0x7aa3	600 Series PCH-H SMBus
+product INTEL 6HS_H_SPI		0x7aa4	600 Series PCH-H SPI (FLASH)
+product INTEL 6HS_H_TRACE	0x7aa6	600 Series PCH-H Trace Hub
+product INTEL 6HS_H_SSRAM	0x7aa7	600 Series PCH-H Shared SRAM
+product INTEL 6HS_H_UART_0	0x7aa8	600 Series PCH-H UART 0
+product INTEL 6HS_H_UART_1	0x7aa9	600 Series PCH-H UART 1
+product INTEL 6HS_H_GSPI_0	0x7aaa	600 Series PCH-H GSPI 0
+product INTEL 6HS_H_GSPI_1	0x7aab	600 Series PCH-H GSPI 1
+product INTEL 6HS_H_PCIE_9	0x7ab0	600 Series PCH-H PCIe RP 9
+product INTEL 6HS_H_PCIE_10	0x7ab1	600 Series PCH-H PCIe RP 10
+product INTEL 6HS_H_PCIE_11	0x7ab2	600 Series PCH-H PCIe RP 11
+product INTEL 6HS_H_PCIE_12	0x7ab3	600 Series PCH-H PCIe RP 12
+product INTEL 6HS_H_PCIE_13	0x7ab4	600 Series PCH-H PCIe RP 13
+product INTEL 6HS_H_PCIE_14	0x7ab5	600 Series PCH-H PCIe RP 14
+product INTEL 6HS_H_PCIE_15	0x7ab6	600 Series PCH-H PCIe RP 15
+product INTEL 6HS_H_PCIE_16	0x7ab7	600 Series PCH-H PCIe RP 16
+product 

CVS commit: src/sys/dev/pci

2022-01-25 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Tue Jan 25 16:06:44 UTC 2022

Modified Files:
src/sys/dev/pci: pcidevs

Log Message:
Add Alder Lake devices and Intel 600 Series PCH devices.


To generate a diff of this commit:
cvs rdiff -u -r1.1445 -r1.1446 src/sys/dev/pci/pcidevs

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



Re: CVS commit: src/tests/lib/libcurses

2022-01-25 Thread Martin Husemann
On Tue, Jan 25, 2022 at 03:23:05AM +, Brett Lymn wrote:
> Module Name:  src
> Committed By: blymn
> Date: Tue Jan 25 03:23:05 UTC 2022
> 
> Modified Files:
>   src/tests/lib/libcurses: debug_test t_curses.sh
>   src/tests/lib/libcurses/check_files: add_wch3.chk get_wstr.chk
>   getn_wstr.chk ins_wch1.chk ins_wch2.chk ins_wch3.chk mvins_wch.chk
>   wget_wstr.chk wgetn_wstr.chk wins_wch1.chk wins_wch2.chk
>   wins_wch3.chk wvline_set.chk
>   src/tests/lib/libcurses/tests: add_wch ins_wch overwrite
> 
> Log Message:
> Update of tests to account for output changes associated with wide char
> fixes.  Also, default all tests to using UTF8 instead of doing a special
> dance for the wide character tests and fix debug_test to force set the
> locale to UTF8 so tests under debug don't throw spurious mismatches
> when a wide character test is run.

This makes them all fail for me:

Tests root: /usr/tests/lib/libcurses

t_curses (1/1): 201 test cases
add_wch: [0.174435s] Failed: Test case exited normally but failed to create 
the results file: Failed to open /tmp/atf-run.dxlAhY/tcr
addbytes: [0.152203s] Failed: Test case exited normally but failed to 
create the results file: Failed to open /tmp/atf-run.dxlAhY/tcr
[..]

Martin


CVS commit: src/sys/dev/usb

2022-01-25 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Tue Jan 25 11:17:39 UTC 2022

Modified Files:
src/sys/dev/usb: xhci.c

Log Message:
Accept USB 3.2 in xhci_id_protocols().


To generate a diff of this commit:
cvs rdiff -u -r1.153 -r1.154 src/sys/dev/usb/xhci.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/xhci.c
diff -u src/sys/dev/usb/xhci.c:1.153 src/sys/dev/usb/xhci.c:1.154
--- src/sys/dev/usb/xhci.c:1.153	Sun Jan 16 20:25:36 2022
+++ src/sys/dev/usb/xhci.c	Tue Jan 25 11:17:39 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: xhci.c,v 1.153 2022/01/16 20:25:36 riastradh Exp $	*/
+/*	$NetBSD: xhci.c,v 1.154 2022/01/25 11:17:39 msaitoh Exp $	*/
 
 /*
  * Copyright (c) 2013 Jonathan A. Kollasch
@@ -34,7 +34,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: xhci.c,v 1.153 2022/01/16 20:25:36 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: xhci.c,v 1.154 2022/01/25 11:17:39 msaitoh Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_usb.h"
@@ -1179,6 +1179,7 @@ xhci_id_protocols(struct xhci_softc *sc,
 	case 0x0300:
 	case 0x0301:
 	case 0x0310:
+	case 0x0320:
 		aprint_debug_dev(sc->sc_dev, " %s ports %d - %d\n",
 		major == 3 ? "ss" : "hs", cpo, cpo + cpc -1);
 		break;



CVS commit: src/sys/dev/usb

2022-01-25 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Tue Jan 25 11:17:39 UTC 2022

Modified Files:
src/sys/dev/usb: xhci.c

Log Message:
Accept USB 3.2 in xhci_id_protocols().


To generate a diff of this commit:
cvs rdiff -u -r1.153 -r1.154 src/sys/dev/usb/xhci.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/arch/arm/sociox

2022-01-25 Thread Tohru Nishimura
Module Name:src
Committed By:   nisimura
Date:   Tue Jan 25 10:51:36 UTC 2022

Modified Files:
src/sys/arch/arm/sociox: if_scx.c

Log Message:
- don't put const for CFATTACH_DECL_NEW()
- MDIO now senses PHY correctly.


To generate a diff of this commit:
cvs rdiff -u -r1.34 -r1.35 src/sys/arch/arm/sociox/if_scx.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/sociox/if_scx.c
diff -u src/sys/arch/arm/sociox/if_scx.c:1.34 src/sys/arch/arm/sociox/if_scx.c:1.35
--- src/sys/arch/arm/sociox/if_scx.c:1.34	Fri Dec 31 14:25:22 2021
+++ src/sys/arch/arm/sociox/if_scx.c	Tue Jan 25 10:51:36 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_scx.c,v 1.34 2021/12/31 14:25:22 riastradh Exp $	*/
+/*	$NetBSD: if_scx.c,v 1.35 2022/01/25 10:51:36 nisimura Exp $	*/
 
 /*-
  * Copyright (c) 2020 The NetBSD Foundation, Inc.
@@ -46,7 +46,7 @@
 #define NOT_MP_SAFE	0
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: if_scx.c,v 1.34 2021/12/31 14:25:22 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_scx.c,v 1.35 2022/01/25 10:51:36 nisimura Exp $");
 
 #include 
 #include 
@@ -546,10 +546,10 @@ static void scx_fdt_attach(device_t, dev
 static int scx_acpi_match(device_t, cfdata_t, void *);
 static void scx_acpi_attach(device_t, device_t, void *);
 
-const CFATTACH_DECL_NEW(scx_fdt, sizeof(struct scx_softc),
+CFATTACH_DECL_NEW(scx_fdt, sizeof(struct scx_softc),
 scx_fdt_match, scx_fdt_attach, NULL, NULL);
 
-const CFATTACH_DECL_NEW(scx_acpi, sizeof(struct scx_softc),
+CFATTACH_DECL_NEW(scx_acpi, sizeof(struct scx_softc),
 scx_acpi_match, scx_acpi_attach, NULL, NULL);
 
 static void scx_attach_i(struct scx_softc *);
@@ -683,9 +683,6 @@ scx_fdt_attach(device_t parent, device_t
 	const char *phy_type;
 	long ref_clk;
 
-	aprint_naive("\n");
-	aprint_normal(": Socionext Gigabit Ethernet controller\n");
-
 	if (fdtbus_get_reg(phandle, 0, addr+0, size+0) != 0
 	|| bus_space_map(faa->faa_bst, addr[0], size[0], 0, ) != 0) {
 		aprint_error_dev(self, "unable to map device csr\n");
@@ -731,6 +728,7 @@ scx_fdt_attach(device_t parent, device_t
 	sc->sc_phy_id = phy_id;
 	sc->sc_freq = ref_clk;
 
+	aprint_normal("%s", device_xname(self));
 	scx_attach_i(sc);
 	return;
  fail:
@@ -762,15 +760,11 @@ scx_acpi_attach(device_t parent, device_
 	ACPI_INTEGER phy_type, phy_id, ref_freq;
 	ACPI_STATUS rv;
 
-	aprint_naive("\n");
-	aprint_normal(": Socionext Gigabit Ethernet controller\n");
-
 	rv = acpi_resource_parse(self, handle, "_CRS",
 	, _resource_parse_ops_default);
-	if (ACPI_FAILURE(rv)) {
-		aprint_error_dev(self, "missing crs resources\n");
+	if (ACPI_FAILURE(rv))
 		return;
-	}
+
 	mem = acpi_res_mem(, 0);
 	irq = acpi_res_irq(, 0);
 	if (mem == NULL || irq == NULL || mem->ar_length == 0) {
@@ -783,8 +777,8 @@ scx_acpi_attach(device_t parent, device_
 		return;
 	}
 	sc->sc_sz = mem->ar_length;
-	sc->sc_ih = acpi_intr_establish(self, (uint64_t)handle, IPL_NET,
-	NOT_MP_SAFE, scx_intr, sc, device_xname(self));
+	sc->sc_ih = acpi_intr_establish(self, (uint64_t)(uintptr_t)handle,
+	IPL_NET, NOT_MP_SAFE, scx_intr, sc, device_xname(self));
 	if (sc->sc_ih == NULL) {
 		aprint_error_dev(self, "couldn't establish interrupt\n");
 		goto fail;
@@ -808,7 +802,7 @@ scx_acpi_attach(device_t parent, device_
 	}
 	rv = acpi_dsd_integer(handle, "phy-channel", _id);
 	if (ACPI_FAILURE(rv))
-		phy_id = 7;
+		phy_id = MII_PHY_ANY;
 	rv = acpi_dsd_integer(handle, "socionext,phy-clock-frequency",
 			_freq);
 	if (ACPI_FAILURE(rv))
@@ -819,15 +813,14 @@ scx_acpi_attach(device_t parent, device_
 	sc->sc_sh = bsh;
 	sc->sc_eesh = eebsh;
 	sc->sc_dmat = aa->aa_dmat64;
-
-aprint_normal_dev(self,
-"phy type %d, phy id %d, freq %ld\n", (int)phy_type, (int)phy_id, ref_freq);
 	sc->sc_100mii = (phy_type != 1000);
 	sc->sc_phy_id = (int)phy_id;
 	sc->sc_freq = ref_freq;
+
 aprint_normal_dev(self,
-"GMACGAR %08x\n", mac_read(sc, GMACGAR));
+"phy type %d, phy id %d, freq %ld\n", (int)phy_type, (int)phy_id, ref_freq);
 
+	aprint_normal("%s", device_xname(self));
 	scx_attach_i(sc);
 
 	acpi_resource_cleanup();
@@ -847,22 +840,23 @@ scx_attach_i(struct scx_softc *sc)
 	struct ifnet * const ifp = >sc_ethercom.ec_if;
 	struct mii_data * const mii = >sc_mii;
 	struct ifmedia * const ifm = >mii_media;
-	uint32_t which, dwimp, dwfea;
+	uint32_t which, dwfea, dwimp;
 	uint8_t enaddr[ETHER_ADDR_LEN];
 	bus_dma_segment_t seg;
 	uint32_t csr;
 	int i, nseg, error = 0;
 
+	aprint_naive("\n");
+	aprint_normal(": Socionext Gigabit Ethernet controller\n");
+
 	which = CSR_READ(sc, HWVER);	/* Socionext version 5.00xx */
-	dwimp = mac_read(sc, GMACIMPL);	/* DWC EMAC XX.YY */
-	dwfea = mac_read(sc, HWFEA);	/* DWC feature */
+	dwfea = mac_read(sc, HWFEA);	/* DWC feature bits */
+	dwimp = mac_read(sc, GMACIMPL);	/* DWC implementation XX.YY */
 	aprint_normal_dev(sc->sc_dev,
-	"Socionext NetSec GbE %x.%x"
-	" (impl 0x%x, feature 0x%x)\n",
-	which >> 

CVS commit: src/sys/arch/arm/sociox

2022-01-25 Thread Tohru Nishimura
Module Name:src
Committed By:   nisimura
Date:   Tue Jan 25 10:51:36 UTC 2022

Modified Files:
src/sys/arch/arm/sociox: if_scx.c

Log Message:
- don't put const for CFATTACH_DECL_NEW()
- MDIO now senses PHY correctly.


To generate a diff of this commit:
cvs rdiff -u -r1.34 -r1.35 src/sys/arch/arm/sociox/if_scx.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/arch/arm/sociox

2022-01-25 Thread Tohru Nishimura
Module Name:src
Committed By:   nisimura
Date:   Tue Jan 25 10:38:56 UTC 2022

Modified Files:
src/sys/arch/arm/sociox: sni_gpio.c

Log Message:
- rectify attach messages.
- abandon irq to use for now.


To generate a diff of this commit:
cvs rdiff -u -r1.12 -r1.13 src/sys/arch/arm/sociox/sni_gpio.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/sociox/sni_gpio.c
diff -u src/sys/arch/arm/sociox/sni_gpio.c:1.12 src/sys/arch/arm/sociox/sni_gpio.c:1.13
--- src/sys/arch/arm/sociox/sni_gpio.c:1.12	Tue Dec 21 06:00:45 2021
+++ src/sys/arch/arm/sociox/sni_gpio.c	Tue Jan 25 10:38:56 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: sni_gpio.c,v 1.12 2021/12/21 06:00:45 nisimura Exp $	*/
+/*	$NetBSD: sni_gpio.c,v 1.13 2022/01/25 10:38:56 nisimura Exp $	*/
 
 /*-
  * Copyright (c) 2020 The NetBSD Foundation, Inc.
@@ -34,7 +34,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: sni_gpio.c,v 1.12 2021/12/21 06:00:45 nisimura Exp $");
+__KERNEL_RCSID(0, "$NetBSD: sni_gpio.c,v 1.13 2022/01/25 10:38:56 nisimura Exp $");
 
 #include 
 #include 
@@ -94,14 +94,13 @@ CFATTACH_DECL_NEW(snigpio_acpi, sizeof(s
  *PowerButton (PWROFF#) can be detectable.
  *
  *  DevelopmentBox has 96board mezzanine 2x 20 receptacle
- *gpio  "/gpio@5100" pinA-L (10-25) down edge sensitive
+ *gpio  "/gpio@5100" pinA-L (23-34) down edge sensitive
  *i2c   "/i2c1@51221000"
  *spi   "/spi1@5481"
  *uart0 "/uart@2a40" pin1-4 for real S2C11 console
  *uart1 SCP secure co-prorcessor uart console in pin5-6
  */
 static void snigpio_attach_i(struct snigpio_softc *);
-static int snigpio_intr(void *);
 
 static const struct device_compatible_entry compat_data[] = {
 	{ .compat = "socionext,synquacer-gpio" },
@@ -130,32 +129,12 @@ snigpio_fdt_attach(device_t parent, devi
 	bus_space_handle_t ioh;
 	bus_addr_t addr;
 	bus_size_t size;
-	char intrstr[128];
-	const char *list;
-
-	aprint_naive("\n");
-	aprint_normal(": Socionext GPIO controller\n");
 
 	if (fdtbus_get_reg(phandle, 0, , ) != 0
 	|| bus_space_map(faa->faa_bst, addr, size, 0, ) != 0) {
 		aprint_error_dev(self, "unable to map device\n");
 		return;
 	}
-	if (!fdtbus_intr_str(phandle, 0, intrstr, sizeof(intrstr))) {
-		aprint_error_dev(self, "failed to decode interrupt\n");
-		goto fail;
-	}
-	sc->sc_ih = fdtbus_intr_establish(phandle,
-			0, IPL_VM, 0, snigpio_intr, sc);
-	if (sc->sc_ih == NULL) {
-		aprint_error_dev(self, "couldn't establish interrupt\n");
-		goto fail;
-	}
-	aprint_normal_dev(self, "interrupting on %s\n", intrstr);
-
-	list = fdtbus_get_string(phandle, "gpio-line-names");
-	if (list)
-		aprint_normal_dev(self, "%s\n", list);
 
 	sc->sc_dev = self;
 	sc->sc_iot = faa->faa_bst;
@@ -163,13 +142,11 @@ snigpio_fdt_attach(device_t parent, devi
 	sc->sc_iob = addr;
 	sc->sc_ios = size;
 	sc->sc_phandle = phandle;
+	/* could use FDI "gpio-line-names" array via device_set_handle() */
 
 	snigpio_attach_i(sc);
 
 	return;
- fail:
-	bus_space_unmap(sc->sc_iot, sc->sc_ioh, sc->sc_ios);
-	return;	
 }
 
 static int
@@ -189,22 +166,16 @@ snigpio_acpi_attach(device_t parent, dev
 	bus_space_handle_t ioh;
 	struct acpi_resources res;
 	struct acpi_mem *mem;
-	struct acpi_irq *irq;
 	ACPI_STATUS rv;
 	char *list;
 
-	aprint_naive("\n");
-	aprint_normal(": Socionext GPIO controller\n");
-
 	rv = acpi_resource_parse(self, aa->aa_node->ad_handle, "_CRS",
 	, _resource_parse_ops_default);
-	if (ACPI_FAILURE(rv)) {
-		aprint_error_dev(self, "missing crs resources\n");
+	if (ACPI_FAILURE(rv))
 		return;
-	}
+
 	mem = acpi_res_mem(, 0);
-	irq = acpi_res_irq(, 0);
-	if (mem == NULL || irq == NULL || mem->ar_length == 0) {
+	if (mem == NULL || mem->ar_length == 0) {
 		aprint_error_dev(self, "incomplete resources\n");
 		return;
 	}
@@ -213,30 +184,19 @@ snigpio_acpi_attach(device_t parent, dev
 		aprint_error_dev(self, "couldn't map registers\n");
 		return;
 	}
-	sc->sc_ih = acpi_intr_establish(self, (uint64_t)handle,
-	IPL_VM, false, snigpio_intr, sc, device_xname(self));
-	if (sc->sc_ih == NULL) {
-		aprint_error_dev(self, "couldn't establish interrupt\n");
-		goto fail;
-	}
-	rv = acpi_dsd_string(handle, "gpio-line-names", );
-	if (ACPI_SUCCESS(rv))
-		aprint_normal_dev(self, "%s\n", list);
 
 	sc->sc_dev = self;
 	sc->sc_iot = aa->aa_memt;
 	sc->sc_ioh = ioh;
 	sc->sc_ios = mem->ar_length;
 	sc->sc_phandle = 0;
+	/* UEFI provides "gpio-line-names" for us */
 
+	aprint_normal("%s", device_xname(self));
 	snigpio_attach_i(sc);
 
 	acpi_resource_cleanup();
 	return;
- fail:
-	acpi_resource_cleanup();
-	bus_space_unmap(sc->sc_iot, sc->sc_ioh, sc->sc_ios);
-	return;	
 }
 
 static void
@@ -245,6 +205,9 @@ snigpio_attach_i(struct snigpio_softc *s
 	struct gpio_chipset_tag	*gc;
 	struct gpiobus_attach_args gba;
 
+	

CVS commit: src/sys/arch/arm/sociox

2022-01-25 Thread Tohru Nishimura
Module Name:src
Committed By:   nisimura
Date:   Tue Jan 25 10:38:56 UTC 2022

Modified Files:
src/sys/arch/arm/sociox: sni_gpio.c

Log Message:
- rectify attach messages.
- abandon irq to use for now.
@@ -94,14 +94,13 @@ CFATTACH_DECL_NEW(snigpio_acpi, sizeof(s
  *i2c   "/i2c1@51221000"
  *spi   "/spi1@5481"
- *uart0 "/uart@2a40" pin1-4 for real S2C11 console
- *uart1 SCP secure co-prorcessor uart console in pin5-6
+ *uart0 "/uart@2a40" pin3,5,7,9 for real S2CA11 console
+ *uart1 SCP secure co-prorcessor uart console in pin11,13
  */
 static void snigpio_attach_i(struct snigpio_softc *);


To generate a diff of this commit:
cvs rdiff -u -r1.12 -r1.13 src/sys/arch/arm/sociox/sni_gpio.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.